@@ -15,7 +15,7 @@ use warnings;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(debug $DEBUG carp_once);
 our %EXPORT_TAGS = (all => [ @EXPORT_OK ]);
-our $VERSION = '0.77';
+our $VERSION = '0.78';
 our $DUMPSIG;
 
 our ($DEBUG, $DEBUG_FH, %_CARPED, 
@@ -161,6 +161,7 @@ sub parent_dump {
     #     total completed jobs
     #     completed job distribution of run times
     my ($dump_completed_jobs) = @_;
+    no warnings 'once';
 
     if ($$ != $Forks::Super::MAIN_PID) {
 	# this is not the main fork, so we should do the
@@ -208,7 +209,9 @@ sub parent_dump {
     my $num_reaped = 0;
     foreach my $job (@Forks::Super::ALL_JOBS) {
 	if ($job->is_active || $job->{state} eq 'SUSPENDED') {
-	    print $TTY "ACTIVE JOBS\n-----------\n\n" unless $header++;
+            if (!$header++) {
+                print $TTY "ACTIVE JOBS\n-----------\n\n";
+            }
 	    _dump_job($TTY, $job);
 	    $num_active++;
 	}
@@ -218,7 +221,9 @@ sub parent_dump {
     $header = 0;
     foreach my $job (@Forks::Super::ALL_JOBS) {
 	if ($job->is_deferred) {
-	    print $TTY "QUEUED JOBS\n-----------\n\n" unless $header++;
+            if (!$header++) {
+                print $TTY "QUEUED JOBS\n-----------\n\n";
+            }
 	    _dump_job($TTY, $job, 'queue');
 	    $num_deferred++;
 	}
@@ -231,7 +236,9 @@ sub parent_dump {
 	foreach my $job (@Forks::Super::ALL_JOBS, 
 			 @Forks::Super::Job::ARCHIVED_JOBS) {
 	    if ($job->is_complete) {
-		print $TTY "COMPLETE JOBS\n-------------\n\n" unless $header++;
+                if (!$header++) {
+                    print $TTY "COMPLETE JOBS\n-------------\n\n";
+                }
 		_dump_job($TTY, $job);
 		push @run_times, $job->{end} - $job->{start};
 		$num_complete++;
@@ -245,8 +252,10 @@ sub parent_dump {
     foreach my $job (@Forks::Super::ALL_JOBS, 
 		     @Forks::Super::Job::ARCHIVED_JOBS) {
 	if (!$job->is_active && !$job->is_complete
-	        && !$job->is_deferred && !$job->is_suspended) {
-	    print $TTY "OTHER JOBS\n----------\n\n" unless $header++;
+                && !$job->is_deferred && !$job->is_suspended) {
+            if (!$header++) {
+                print $TTY "OTHER JOBS\n----------\n\n";
+            }
 	    _dump_job($TTY,$job);
 	    $num_other++;
 	}
@@ -259,9 +268,12 @@ sub parent_dump {
 	print $TTY "Deferred jobs: $num_deferred\n" if $num_deferred;
 	if ($num_complete) {
 	    my ($x,$x2) = (0,0);
-	    $x+=$_, $x2+=$_*$_ for @run_times;
+            for my $run_time(@run_times) {
+                $x += $run_time;
+                $x2 += $run_time * $run_time;
+            }
 	    $x /= @run_times;
-	    $x2 /= @run_times;
+ 	    $x2 /= @run_times;
 	    $x2 -= $x*$x;
 	    $x2 = $x2 > 0 ? sqrt($x2) : 0.0;  # stdev of run times
 	    printf $TTY ("Completed jobs: %d (%d reaped)  "
@@ -271,7 +283,6 @@ sub parent_dump {
 	print $TTY "Other jobs    : $num_other\n" if $num_other;
 	print $TTY "\n";
     }
-
     close $TTY;
     return;
 }
@@ -420,7 +431,7 @@ Forks::Super::Debug - debugging and logging routines for Forks::Super distro
 
 =head1 VERSION
 
-0.77
+0.78
 
 =head1 VARIABLES
 
@@ -504,8 +515,8 @@ will respond to that signal by dumping information about all processes
 to the console. If the argument is a true value but not a signal name,
 the program will respond to C<SIGQUIT> signals.
 
-This feature may also be enabled upon import of L<Forks::Super> using
-the C<ENABLE_DUMP> arg. For example,
+This feature may also be enabled upon import of 
+L<Forks::Super|Forks::Super> using the C<ENABLE_DUMP> arg. For example,
 
     use Forks::Super ENABLE_DUMP => 'USR1';
 
@@ -529,7 +540,7 @@ Marty O'Brien, E<lt>mob@cpan.orgE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2009-2013, Marty O'Brien.
+Copyright (c) 2009-2015, Marty O'Brien.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
