@@ -23,12 +23,12 @@ use IO::Handle;
 use strict;
 use warnings;
 
-eval "use Devel::GlobalDestruction";
+eval 'use Devel::GlobalDestruction';
 
 our @ISA = qw(Exporter);
 our @EXPORT = qw(@ALL_JOBS %ALL_JOBS PREFORK POSTFORK 
                  POSTFORK_PARENT POSTFORK_CHILD);
-our $VERSION = '0.77';
+our $VERSION = '0.78';
 
 our (@ALL_JOBS, %ALL_JOBS, @ARCHIVED_JOBS, $WIN32_PROC, $WIN32_PROC_PID);
 our $OVERLOAD_ENABLED = 0;
@@ -161,12 +161,12 @@ sub is_daemon {
     return !!$job->{daemon};
 }
 
-sub waitpid {
+sub Forks::Super::Job::waitpid {
     my ($job, $flags, $timeout) = @_;
     return Forks::Super::Wait::waitpid($job->{pid}, $flags, $timeout || 0);
 }
 
-sub wait {
+sub Forks::Super::Job::wait {
     my ($job, $timeout) = @_;
     if (defined($timeout) && $timeout == 0) {
 	return Forks::Super::Wait::waitpid($job->{pid}, &WNOHANG);
@@ -174,7 +174,7 @@ sub wait {
     return Forks::Super::Wait::waitpid($job->{pid}, 0, $timeout || 0);
 }
 
-sub kill {
+sub Forks::Super::Job::kill {
     my ($job, $signal) = @_;
     if (!defined($signal) || $signal eq '') {
 	$signal = Forks::Super::Util::signal_number('INT') || 1;
@@ -182,7 +182,7 @@ sub kill {
     return Forks::Super::kill($signal, $job);
 }
 
-sub state {
+sub Forks::Super::Job::state {
     my $job = shift;
     if ($job->{daemon} && 
 	$job->{state} ne 'NEW' &&
@@ -1090,7 +1090,7 @@ sub _postlaunch_child_to_remote_cmd {
             exit $c1 >> 8;
         } elsif (CONFIG_module("Net::SSH::Perl")) {
 
-            open TTY,'>/dev/tty';
+            open my $TTY,'>/dev/tty';
 
             my ($user,$host) = split /\@/, $remote->{host};
             if (!defined $host) {
@@ -1104,13 +1104,13 @@ sub _postlaunch_child_to_remote_cmd {
 
             if ($remote->{password}) {
                 my $login_ok = $ssh->login($user, $remote->{password}, 1);
-                print TTY "login[1]: $login_ok\n";
+                print $TTY "login[1]: $login_ok\n";
                 if (!$login_ok) {
                     # ...
                 }
             } else {
                 my $login_ok = $ssh->login($user, "", 1);
-                print TTY "login[2]: $login_ok\n";
+                print $TTY "login[2]: $login_ok\n";
                 if (!$login_ok) {
                     # ...
                 }
@@ -1766,8 +1766,11 @@ sub this {
 sub _config_child {
     my $job = shift;
 
-    # $Forks::Super::Job::self  is deprecated
-    $Forks::Super::Job::self = $job;
+    {
+        no warnings 'once';
+        # $Forks::Super::Job::self  is deprecated
+        $Forks::Super::Job::self = $job;
+    }
     $this = $job;
 
     $job->_config_env_child;
@@ -2273,7 +2276,7 @@ Forks::Super::Job - object representing a background task
 
 =head1 VERSION
 
-0.77
+0.78
 
 =head1 SYNOPSIS
 
