@@ -33,11 +33,12 @@ $| = 1;
 
 our @ISA = qw(Exporter);
 our @EXPORT = qw(close_fh);
-our $VERSION = '0.77';
+our $VERSION = '0.78';
+our $NO_README = 0;
 
 our (%FILENO, %SIG_OLD, $IPC_COUNT, $IPC_DIR_DEDICATED,
      @IPC_FILES, %IPC_FILES);
-our ($SIGNALS_TRAPPED, $_CLEANUP, $_SIGNAL_TRAPPED_SO_SUPPRESS_INFO) = (0,0,0);
+our $_CLEANUP = 0;
 our $MAIN_PID = $$;
 our $__OPEN_FH = 0; # for debugging, monitoring file handle usage. Not ready.
 our $__MAX_OPEN_FH = do {
@@ -103,8 +104,8 @@ my $cleanse_mode = 0;
     my $seq = 1000;     # an arbitrary starting point
 
     sub _gensym () {
-	no strict 'refs';
 	my $name = join '_', @_, "IO$$", $seq++;
+	no strict 'refs';
 	my $ref = \*{$pkg . $name};
 	delete $$pkg{$name};
 	return $ref;
@@ -159,6 +160,7 @@ sub _safeopen ($*$$;%) {
                   "open file handles. Consider closing unused file " .
                   "handles");
         }
+        no warnings 'once';
 	$Forks::Super::Job::Ipc::TOO_MANY_OPEN_FH_WARNINGS++;
 
 	try_to_close_some_open_filehandles();
@@ -312,7 +314,10 @@ sub _handle_safeopen_failure {
 }
 
 sub try_to_close_some_open_filehandles {
-    return if 'rescue' ne $Forks::Super::ON_TOO_MANY_OPEN_FILEHANDLES;
+    {
+        no warnings 'once';
+        return if 'rescue' ne $Forks::Super::ON_TOO_MANY_OPEN_FILEHANDLES;
+    }
     my $nclosed = 0;
 
     # in the child, you can close file handles from unrelated jobs ...
@@ -860,11 +865,6 @@ sub _create_socket_pair {
     return ($s_child,$s_parent);
 }
 
-sub ___fileno {
-    my $fh = shift;
-    return $FILENO{$fh};
-}
-
 sub _create_pipe_pair {
     my $job = shift;
     if (!defined($job)) {
@@ -937,6 +937,7 @@ sub _register_ipc_file {
     if (defined $info) {
 	$IPC_FILES{$file} = $info;
     }
+    return;
 }
 
 #
@@ -1013,7 +1014,6 @@ sub set_ipc_dir {
     }
 
     # success.
-    $Forks::Super::FH_DIR = "$dir/$dedicated_dirname";   # deprecated
 
     $_IPC_DIR = "$dir/$dedicated_dirname";
     # $Forks::Super::IPC_DIR is tied to this variable
@@ -1022,12 +1022,11 @@ sub set_ipc_dir {
     debug("dedicated IPC directory: $_IPC_DIR") if $DEBUG;
 
     # create README
-    if (!$Forks::Super::Job::Ipc::NO_README && !$cleanse_mode) {
+    if (!$NO_README && !$cleanse_mode) {
 	my $readme = "$_IPC_DIR/README.txt";
 	my $localtime1 = time;
 	my $localtime2 = scalar localtime;
-	if (open my $readme_fh, '>', $readme) {
-	    print $readme_fh <<"____";
+        my $readme_txt = <<"____";
 This directory was created by $^O process $$ at
 $localtime2
 $localtime1 $$
@@ -1043,6 +1042,8 @@ and any other IPC litter.
 
 ____
             #';
+	if (open my $readme_fh, '>', $readme) {
+	    print $readme_fh  $readme_txt;
             close $readme_fh;
 	    _register_ipc_file( $readme,
 				[ purpose => 'README' ] );
@@ -1120,7 +1121,6 @@ sub _choose_dedicated_dirname {
 }
 
 sub _cleanup {
-
     no warnings 'once';
     return if ($Forks::Super::DONT_CLEANUP || 0) > 0;
     return if !defined $_IPC_DIR;
@@ -1133,23 +1133,6 @@ sub _cleanup {
     return;
 }
 
-sub __cleanup__ {
-    my $SIG = shift;
-    if ($DEBUG) {
-	debug("trapping: SIG$SIG");
-    }
-    _untrap_signals() if defined &_untrap_signals;
-    if ($DEBUG) {
-	print STDERR "$$ received $SIG -- cleaning up\n";
-    } else {
-	$_SIGNAL_TRAPPED_SO_SUPPRESS_INFO = 1;
-    }
-    if (&IS_WIN32) {
-	END_cleanup_MSWin32();
-    }
-    exit 1;
-}
-
 # maintenance routine to erase all directories that look like
 # temporary IPC directories.
 #
@@ -1310,7 +1293,7 @@ sub _END_foreground_cleanup {
 sub _END_background_cleanup1 {
     # rename process, if supported by the OS, to note that we are cleaning up
     # not everyone will like this "feature"
-    $0 = "Forks::Super:cleanup:$0";
+    local $0 = "Forks::Super:cleanup:$0";
     sleep 3;
 
     # removing all the files we created during IPC
@@ -2176,6 +2159,7 @@ sub _config_fh_child_stress {
 #	    _safeopen($job, *$glob, '>&', $fh);
 	}
     }
+    return;
 }
 
 sub _config_fh_child_stderr {
@@ -2929,9 +2913,6 @@ sub _getc {
 
 sub _getc_socket {
     my ($sh, $job, %options) = @_;
-
-    local $Devel::DumpTrace::TRACE = 1;
-
     return if !__sanitize_read_inputs($sh, $job, 0, %options);
     my $zz = eval { $sh->opened };
     if ($@) {
@@ -3254,10 +3235,9 @@ sub init_child {
 }
 
 sub deinit_child {
-
+    use Data::Dumper;
     my $job = Forks::Super::Job->this;
     if (defined($job->{share}) && defined($job->{share_ipc})) {
-	use Data::Dumper;
 	if (open my $fh, '>', $job->{share_ipc}) {
 	    print $fh Data::Dumper::Dumper( $job->{share} );
 	    close $fh;
