@@ -14,7 +14,7 @@ use strict;
 use warnings;
 require Forks::Super::Job::OS::Win32 if &IS_WIN32 || &IS_CYGWIN;
 
-our $VERSION = '0.77';
+our $VERSION = '0.78';
 
 our $CPU_AFFINITY_CALLS = 0;
 our $OS_PRIORITY_CALLS = 0;
@@ -22,10 +22,10 @@ our $OS_PRIORITY_CALLS = 0;
 sub _preconfig_os {
     my $job = shift;
     if (defined $job->{cpu_affinity}) {
-	$job->{cpu_affinity_call} = ++$CPU_AFFINITY_CALLS;
+        $job->{cpu_affinity_call} = ++$CPU_AFFINITY_CALLS;
     }
     if (defined $job->{os_priority}) {
-	$job->{os_priority_call} = ++$OS_PRIORITY_CALLS;
+        $job->{os_priority_call} = ++$OS_PRIORITY_CALLS;
     }
     return;
 }
@@ -166,12 +166,13 @@ sub get_cpu_load {
     }
 
     if (-r '/proc/loadavg' && $^O ne 'cygwin') {
-	open my $fh, '<', '/proc/loadavg';
-	my $line = <$fh>;
-	close $fh;
-	if ($line =~ /^(\d+[.,]\d+)\s+(\d+[.,]\d+)\s+(\d+[.,]\d+)/) {
-	    return $1;
-	}
+	if (open my $fh, '<', '/proc/loadavg') {
+            my $line = <$fh>;
+            close $fh;
+            if ($line =~ /^(\d+[.,]\d+)\s+(\d+[.,]\d+)\s+(\d+[.,]\d+)/) {
+                return $1;
+            }
+        }
     }
 
     # else pray for `uptime`.
