@@ -18,7 +18,7 @@ use warnings;
 use constant FOREVER => 9E9;
 use constant LONG_TIME => 9E8;
 
-our $VERSION = '0.77';
+our $VERSION = '0.78';
 
 our $MAIN_PID = $$;
 our $DISABLE_INT = 0;
@@ -106,8 +106,10 @@ sub Forks::Super::Job::_config_timeout_child {
     # abort after 2-4 hours), but I haven't seen this problem in a while
     # (since v0.56?)
 
+    no warnings 'once';
     if ($Forks::Super::SysInfo::SLEEP_ALARM_COMPATIBLE <= 0
 	|| !$Forks::Super::SysInfo::CONFIG{'alarm'}
+        || $Forks::Super::SysInfo::PREFER_ALTERNATE_ALARM
 	|| $job->{use_alternate_alarm}) {
 
 	# can't/shouldn't use alarm for timeout. 
