@@ -11,7 +11,7 @@ use warnings;
 
 our @ISA = qw(Exporter);
 our @EXPORT = qw(bg_eval bg_qx BG_EVAL BG_QX);
-our $VERSION = '0.77';
+our $VERSION = '0.78';
 
 use constant BG_EVAL => 'Forks::Super::bg_eval';
 use constant BG_QX   => 'Forks::Super::bg_qx';
@@ -124,14 +124,14 @@ sub bg_qx {
 # tie $@%result, 'Forks::Super::bg_XXX', ...  statements
 {
     package Forks::Super::bg_eval;
-    sub TIESCALAR ($&;@) {
+    sub TIESCALAR {
 	my ($pkg,$code,@other_options) = @_;
 	my $result = &Forks::Super::LazyEval::bg_eval($code,
 						      @other_options);
 	my $self = { result => $result };
 	bless $self, $pkg;
     }
-    sub TIEARRAY ($&;@) {
+    sub TIEARRAY {
 	my ($pkg,$code,@other_options) = @_;
 	my %options = Forks::Super::LazyEval::_options(@other_options);
 	$options{wantarray} = 1;
@@ -139,7 +139,7 @@ sub bg_qx {
 	my $self = { result => $result, is_array => 1 };
 	bless $self, $pkg;
     }
-    sub TIEHASH ($&;@) {
+    sub TIEHASH {
 	my ($pkg,$code,@other_options) = @_;
 	my %options = Forks::Super::LazyEval::_options(@other_options);
 	$options{wantarray} = 2;
@@ -337,7 +337,7 @@ Forks::Super::LazyEval
 
 =head1 VERSION
 
-0.77
+0.78
 
 =head1 DESCRIPTION
 
