@@ -10,7 +10,7 @@ use Carp;
 use strict;
 use warnings;
 
-our $VERSION = '0.77';
+our $VERSION = '0.78';
 
 # "protocols" for serializing data and the methods used
 # to carry out the serialization
@@ -89,14 +89,6 @@ sub new {
 
     } elsif ($style eq 'qx') {
 	croak "Always use F::S::LazyEval::BackgroundScalar with bg_qx\n";
-	$self->{command} = $command_or_code;
-	$self->{delimiter} = $/;
-	$self->{stdout} = '';
-	$self->{job_id} = Forks::Super::fork {
-	    %other_options, child_fh => 'out',
-	    cmd => $command_or_code,
-	    stdout => \$self->{stdout},
-	    _is_bg => 2};
     }
     $self->{job} = Forks::Super::Job::get($self->{job_id});
     ($Forks::Super::LAST_JOB, $Forks::Super::LAST_JOB_ID)
@@ -212,14 +204,15 @@ Forks::Super::LazyEval::BackgroundArray
 
 =head1 VERSION
 
-0.77
+0.78
 
 =head1 DESCRIPTION
 
 An object type used to implement the L<Forks::Super::bg_qx|Forks::Super/bg_qx>
 and L<Forks::Super::bg_eval|Forks::Super/bg_eval> lazy asynchronous
 evaluation functions for list context.
-See L<Forks::Super> and L<Forks::Super::LazyEval> for details.
+See L<Forks::Super|Forks::Super> and 
+L<Forks::Super::LazyEval|Forks::Super::LazyEval> for details.
 
 =head1 AUTHOR
 
