@@ -58,7 +58,7 @@ use overload # XXX - what is overloading for? is it necessary?
 		         : atan2($_[0]->_fetch, $_[1]) }
 ;
 
-our $VERSION = '0.77';
+our $VERSION = '0.78';
 
 # "protocols" for serializing data and the methods used
 # to carry out the serialization
@@ -230,6 +230,9 @@ sub _fetch {
 
     # temporarily turn off overloaded hash dereferencing.
     # it will be turned back on later
+    #
+    # would like to just say 'no overloading "%{}"', but that is
+    # not supported for perl <v5.10.1
     my $class = $self->_unbless;
 
     if (!$self->{value_set}) {
@@ -298,14 +301,15 @@ Forks::Super::LazyEval::BackgroundScalar
 
 =head1 VERSION
 
-0.77
+0.78
 
 =head1 DESCRIPTION
 
 An object type used to implement the L<Forks::Super::bg_qx|Forks::Super/bg_qx>
 and L<Forks::Super::bg_eval|Forks::Super/bg_eval> lazy asynchronous
 evaluation functions for scalar context.
-See L<Forks::Super> and L<Forks::Super::LazyEval> for details.
+See L<Forks::Super|Forks::Super> and
+L<Forks::Super::LazyEval|Forks::Super::LazyEval> for details.
 
 =head1 AUTHOR
 
