@@ -17,7 +17,7 @@ use warnings;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(queue_job);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
-our $VERSION = '0.77';
+our $VERSION = '0.78';
 
 # must sync FIRST_DEFERRED_ID with Win32 code in Forks::Super::Util::isValidPid
 use constant FIRST_DEFERRED_ID => -500000;
@@ -509,10 +509,10 @@ sub Forks::Super::Queue::InhibitQueueMonitor::STORE {
 
 sub Forks::Super::Queue::QueueInterrupt::STORE {
     my ($self, $new_value) = @_;
-    if (uc $new_value eq uc Forks::Super::Tie::Enum::_get_value($self)) {
+    if (uc $new_value eq uc Forks::Super::Tie::Enum::get_value($self)) {
 	return; # no change
     }
-    if (!Forks::Super::Tie::Enum::_has_attr($self,$new_value)) {
+    if (!Forks::Super::Tie::Enum::has_attr($self,$new_value)) {
 	return; # invalid assignment
     }
     _kill_queue_monitor();
@@ -533,7 +533,7 @@ Forks::Super::Queue
 
 =head1 VERSION
 
-0.77
+0.78
 
 =head1 DESCRIPTION
 
