@@ -14,7 +14,7 @@ use warnings;
 our ($_SIGCHLD, $_SIGCHLD_CNT, $REAP) = (0,0,0);
 our (@CHLD_HANDLE_HISTORY, @SIGCHLD_CAUGHT) = (0);
 our $SIG_DEBUG = $ENV{SIG_DEBUG};
-our $VERSION = '0.77';
+our $VERSION = '0.78';
 my %bastards;
 
 #
@@ -132,7 +132,7 @@ sub handle_bastards {
 	@pids = keys %bastards;
     }
     foreach my $pid (@pids) {
-	my $job = $Forks::Super::Job::ALL_JOBS{$pid};
+	my $job = $Forks::Super::ALL_JOBS{$pid};
 	if (defined $job && defined $bastards{$pid}) {
 	    warn 'Forks::Super: ',
 	        "Job $pid reaped before parent initialization.\n";
