@@ -8,7 +8,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.77';
+our $VERSION = '0.78';
 
 sub new {
     my ($pkg, %args) = @_;
@@ -26,6 +26,7 @@ sub new {
     my $parent = $$;
     my $self;
 
+    no warnings 'once';
     foreach my $impl ($implementation_arg,
 		      @Forks::Super::SysInfo::SYNC_IMPLS,
 		      qw[Semaphlock]) {
@@ -194,7 +195,7 @@ Forks::Super::Sync - portable interprocess synchronization object
 
 =head1 VERSION
 
-0.77
+0.78
 
 =head1 SYNOPSIS
 
@@ -273,8 +274,9 @@ and neither process will hold the third resource.
 
 =item implementation => $implementation
 
-Specifies an implementation of L<Forks::Super::Sync> to use to synchronize
-actions between a parent and child process. Recognized implementations are
+Specifies an implementation of L<Forks::Super::Sync|Forks::Super::Sync> to
+use to synchronize actions between a parent and child process. 
+Recognized implementations are
 
 =over 4
 
@@ -287,18 +289,18 @@ filehandle resources.
 
 =item Win32
 
-Uses L<Win32::Semaphore> objects. As you might expect, only works on
-Windows (including Cygwin).
+Uses L<Win32::Semaphore|Win32::Semaphore> objects. As you might expect, 
+only works on Windows (including Cygwin).
 
 =item Win32Mutex / Win32::Mutex
 
 Another Windows/Cygwin specific synchronization implementation,
-based on L<Win32::Mutex> objects.
+based on L<Win32::Mutex|Win32::Mutex> objects.
 
 =item IPCSemaphore
 
-Uses L<IPC::Semaphore> objects. Works on most Unix-y systems
-(though not Cygwin, for whatever reason).
+Uses L<IPC::Semaphore|IPC::Semaphore> objects. Works on most
+Unix-y systems (though not Cygwin, for whatever reason).
 
 =back
 
@@ -347,16 +349,17 @@ acquiring the resource. Not unlike calling
 =head1 DISCLAIMER
 
 Implementations use and abuse subsets of features of file locking
-and semaphores for the narrow purposes of the L<Forks::Super>
-distribution. It is probably not a good idea to try to use or 
-extend this module for other purposes.
+and semaphores for the narrow purposes of the 
+L<Forks::Super|Forks::Super> distribution. It is probably not a
+good idea to try to use or extend this module for other purposes.
 
 =head1 SEE ALSO
 
-L<Forks::Super>
+L<Forks::Super|Forks::Super>
 
-Various implementations based on L<perlfunc/"flock">, L<IPC::Semaphore>,
-L<Win32::Semaphore>, or L<Win32::Mutex>.
+Various implementations based on L<flock|perlfunc/"flock">,
+L<IPC::Semaphore|IPC::Semaphore>, L<Win32::Semaphore|Win32::Semaphore>,
+or L<Win32::Mutex|Win32::Mutex>.
 
 =head1 AUTHOR
 
