@@ -7,7 +7,7 @@ use POSIX ':sys_wait_h';
 use IPC::SysV qw(IPC_PRIVATE S_IRUSR S_IWUSR IPC_CREAT IPC_NOWAIT);
 use IPC::Semaphore;
 our @ISA = qw(Forks::Super::Sync);
-our $VERSION = '0.77';
+our $VERSION = '0.78';
 
 our $NOWAIT_YIELD_DURATION = 0.05;
 
@@ -22,7 +22,7 @@ sub new {
 
     my $self = bless{ count => $count, initial => [ @initial ] }, $pkg;
 
-    $self->{sems} = eval q{
+    $self->{sems} = eval {
 	IPC::Semaphore->new(
 	    &IPC_PRIVATE, $count, &S_IRUSR|&S_IWUSR|&IPC_CREAT);
     };
@@ -128,7 +128,6 @@ sub acquire {
     }
 
     if ($z > 1) {
-	return "1";
 	return "0 but true";
     }
     return $z;
@@ -174,7 +173,7 @@ without releasing its locks.
 
 =head1 SEE ALSO
 
-L<Forks::Super::Sync>
+L<Forks::Super::Sync|Forks::Super::Sync>
 
 =cut
 
