@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Carp;
 use Time::HiRes;
-our $VERSION = '0.77';
+our $VERSION = '0.78';
 our @ISA = qw(Forks::Super::Sync);
 
 my $ipc_seq = 0;
@@ -18,16 +18,15 @@ sub new {
     bless $self, $pkg;
 
     for my $i (0 .. $count-1) {
-	my $file = _get_filename();
-	$self->_register_ipc_file($file, "count $i");
-	if (open my $fh, '>>', $file) {
-	    $self->{files}[$i] = $file;
-	    close $fh;
-	} else {
-	    carp "could not use $file as a synchronization file: $!";
-	}
+        my $file = _get_filename();
+        $self->_register_ipc_file($file, "count $i");
+        if (open my $fh, '>>', $file) {
+            $self->{files}[$i] = $file;
+            close $fh;
+        } else {
+            carp "could not use $file as a synchronization file: $!";
+        }
     }
-
     return $self;
 }
 
@@ -35,10 +34,10 @@ sub _register_ipc_file {
     my ($self, $filename, $i) = @_;
     if (defined &Forks::Super::Job::Ipc::_register_ipc_file) {
       Forks::Super::Job::Ipc::_register_ipc_file(
-	  $filename, [ purpose => "sync object id $self->{id} $i" ]);
+          $filename, [ purpose => "sync object id $self->{id} $i" ]);
     } else {
-	$self->{unlink} ||= [];
-	push @{$self->{unlink}}, $filename;
+        $self->{unlink} ||= [];
+        push @{$self->{unlink}}, $filename;
     }
     return;
 }
@@ -47,6 +46,7 @@ sub _touch {
   my $file = shift;
   open my $touch, '>>', $file;
   close $touch;
+  return;
 }
 
 sub _releaseAfterFork {
@@ -58,24 +58,23 @@ sub _releaseAfterFork {
     my $wait = time + 5.0;
 
     for my $i (0 .. $self->{count} - 1) {
-	if ($self->{initial}[$i] eq $label) {
-	    my $file = $self->{files}[$i];
-	    if ($file) {
-		my $fh;
-		if (!open $fh, '>>', $file) {
-		    carp 'FS::Sync::Semaphlock::releaseAfterFork: ',
-		        "error acquiring resource $i in $label";
-		    next;
-		}
-		flock $fh, 2;
-		$self->{acquired}[$i] = $fh;
-	    } else {
-		carp 'FS::Sync::Semaphlock::releaseAfterFork: ',
-		    "no resource $i $file to acquire in $label";
-	    }
-	}
+        if ($self->{initial}[$i] eq $label) {
+            my $file = $self->{files}[$i];
+            if ($file) {
+                my $fh;
+                if (!open $fh, '>>', $file) {
+                    carp 'FS::Sync::Semaphlock::releaseAfterFork: ',
+                         "error acquiring resource $i in $label";
+                    next;
+                }
+                flock $fh, 2;
+                $self->{acquired}[$i] = $fh;
+            } else {
+                carp 'FS::Sync::Semaphlock::releaseAfterFork: ',
+                    "no resource $i $file to acquire in $label";
+            }
+        }
     }
-
     return;
 }
 
@@ -83,9 +82,9 @@ sub release {
     my ($self, $n) = @_;
     return if $n<0 || $n>=$self->{count};
     if (defined $self->{acquired}[$n]) {
-	my $z = flock $self->{acquired}[$n], 8;	
-	$self->{acquired}[$n] = undef;
-	return $z;
+        my $z = flock $self->{acquired}[$n], 8;
+        $self->{acquired}[$n] = undef;
+        return $z;
     }
     return;
 }
@@ -95,42 +94,42 @@ sub acquire {
     return if $n<0 || $n>=$self->{count};
     my $file = $self->{files}[$n];
     if (defined $self->{acquired}[$n]) {
-	return -1;
+        return -1;
     }
     my $fh;
 
     # on Cygwin, using fcntl to emulate flock, this open can
     # (intermittently) fail with $! := "Device or resource busy"
     for my $try (1..5) {
-	last if open $fh, '>>', $file;
-	if ($try == 5) {
-	    carp "failed to acquire file resource $file after 5 tries: $!";
-	    return;
-	}
-	Time::HiRes::sleep(0.25 * $try);
+        last if open $fh, '>>', $file;
+        if ($try == 5) {
+            carp "failed to acquire file resource $file after 5 tries: $!";
+            return;
+        }
+        Time::HiRes::sleep(0.25 * $try);
     }
 
     if (defined $timeout) {
-	my $expire = Time::HiRes::time() + $timeout;
-	my $z;
-	do {
-	    $z = flock $fh, 6;
-	    if ($z) {
-		$self->{acquired}[$n] = $fh;
-		return $z;
-	    }
-	    if ($timeout > 0.0) {
-		Time::HiRes::sleep(0.01);
-	    }
-	} while (Time::HiRes::time() < $expire);
-	close $fh;
-	return 0;
+        my $expire = Time::HiRes::time() + $timeout;
+        my $z;
+        do {
+            $z = flock $fh, 6;
+            if ($z) {
+                $self->{acquired}[$n] = $fh;
+                return $z;
+            }
+            if ($timeout > 0.0) {
+                Time::HiRes::sleep(0.01);
+            }
+        } while (Time::HiRes::time() < $expire);
+        close $fh;
+        return 0;
     }
 
     # no timeout
     my $z = flock $fh, 2;
     if ($z) {
-	$self->{acquired}[$n] = $fh;
+        $self->{acquired}[$n] = $fh;
     }
     return $z;
 }
@@ -144,18 +143,20 @@ sub DESTROY {
 }
 
 sub _get_filename {
+    no warnings 'once';
     return sprintf "%s/.sync%03d", $Forks::Super::IPC_DIR, $ipc_seq++;
 }
 
 sub remove {
     my $self = shift;
     foreach my $fh (@{$self->{acquired}}) {
-	if ($fh) {
-	    close $fh;
-	}
+        if ($fh) {
+            close $fh;
+        }
     }
     delete $self->{count};
     $self->{fh} = [];
+    return;
 }
 
 1;
@@ -194,7 +195,7 @@ Disadvantages: creates files, IPC litter. Uses precious filehandles.
 
 =head1 SEE ALSO
 
-L<Forks::Super::Sync>
+L<Forks::Super::Sync|Forks::Super::Sync>
 
 =cut
 
