@@ -7,7 +7,7 @@ use POSIX ':sys_wait_h';
 use Win32::Semaphore;
 
 our @ISA = qw(Forks::Super::Sync);
-our $VERSION = '0.77';
+our $VERSION = '0.78';
 our $NOWAIT_YIELD_DURATION = 250;
 my @RELEASE_ON_EXIT = ();
 
@@ -178,6 +178,7 @@ sub remove {
     my $self = shift;
     $self->release($_) for 0 .. $self->{count} - 1;
     $self->{sem} = [];
+    return;
 }
 
 sub DESTROY {
@@ -211,7 +212,8 @@ Forks::Super::Sync::Win32
 
 =head1 DESCRIPTION
 
-IPC synchronization object implemented with L<Win32::Semaphore>.
+IPC synchronization object implemented with
+L<Win32::Semaphore|Win32::Semaphore>.
 
 Advantages: fast, doesn't create files or use filehandles
 
@@ -219,7 +221,7 @@ Disadvantages: Windows only.
 
 =head1 SEE ALSO
 
-L<Forks::Super::Sync>
+L<Forks::Super::Sync|Forks::Super::Sync>
 
 =cut
 
