@@ -8,7 +8,7 @@ use strict;
 use warnings;
 
 our @ISA = qw(Forks::Super::Sync);
-our $VERSION = '0.77';
+our $VERSION = '0.78';
 our $NOWAIT_YIELD_DURATION = 50; # milliseconds
 
 # Something we have to watch out for is a process dying without
@@ -43,6 +43,7 @@ sub _releaseAfterFork {
 	    $self->acquire($n);
 	}
     }
+    return;
 }
 
 # more robust version of Win32::Mutex->wait.
@@ -136,6 +137,7 @@ sub release {
 
 sub remove {
     $_[0]->DESTROY;
+    return;
 }
 
 sub DESTROY {
@@ -143,6 +145,7 @@ sub DESTROY {
     $self->{DESTROYING} = 1;
     $self->releaseAll;
     $self->{mutex} = [];
+    return;
 }
 
 
@@ -155,7 +158,7 @@ Forks::Super::Sync::Win32Mutex
 
 =head1 VERSION
 
-0.77
+0.78
 
 =head1 SYNOPSIS
 
@@ -175,7 +178,8 @@ Forks::Super::Sync::Win32Mutex
 
 =head1 DESCRIPTION
 
-IPC synchronization object implemented with L<Win32::Mutex>.
+IPC synchronization object implemented with
+L<Win32::Mutex|Win32::Mutex>.
 
 Advantages: fast, doesn't create files or use filehandles
 
@@ -184,6 +188,6 @@ releasing its locks.
 
 =head1 SEE ALSO
 
-L<Forks::Super::Sync>
+L<Forks::Super::Sync|Forks::Super::Sync>
 
 =cut
