@@ -38,7 +38,7 @@ sub STORE {
     return;
 }
 
-sub _has_attr {
+sub has_attr {
     my ($obj, $value) = @_;
     foreach my $attr (@{$ATTR{$obj}}) {
 	if (uc $value eq uc $attr) {
@@ -48,7 +48,7 @@ sub _has_attr {
     return 0;
 }
 
-sub _get_value {
+sub get_value {
     my ($obj) = @_;
     return $VALUE{$obj};
 }
