@@ -24,7 +24,7 @@ use IO::Pipe;
 use IO::Handle;
 
 our @ISA = qw(IO::Pipe IO::Handle);
-our $VERSION = '0.77';
+our $VERSION = '0.78';
 
 sub TIEHANDLE {
     my ($class, $real_pipe, $glob) = @_;
@@ -88,7 +88,7 @@ sub GETC {
     # sysread returns undef on solaris in t/44j. 
     # Is the SIGCHLD causing an interruption?
     {
-	local $!;
+	local $! = 0;
 	my $n = sysread $self->{PIPE}, $buffer, 1;
 	if (!defined $n) {
 	    if ($!{EINTR}) {
