@@ -28,7 +28,7 @@ use IO::Socket;
 use IO::Handle;
 
 our @ISA = qw(IO::Socket IO::Handle);
-our $VERSION = '0.77';
+our $VERSION = '0.78';
 
 # XXX Windows hack. To get smoothly running sockets on Windows it
 #     seems we have to do a slight pause after each write op.
@@ -191,7 +191,7 @@ sub opened {
     return $self->{SOCKET}->opened;
 }
 
-sub shutdown {
+sub Forks::Super::Tie::IPCSocketHandle::shutdown {
     my ($self, $how) = @_;
     my $glob = $self->{GLOB};
     while (defined $$glob->{std_delegate}) {
