@@ -16,7 +16,7 @@ use constant IS_CYGWIN => $^O =~ /cygwin/i;
 use constant IS_WIN32ish => &IS_WIN32 || &IS_CYGWIN;
 
 our @ISA = qw(Exporter);
-our $VERSION = '0.77';
+our $VERSION = '0.78';
 our @EXPORT_OK = qw(Ctime is_number isValidPid pause qualify_sub_name 
 		    is_socket is_pipe IS_WIN32 IS_CYGWIN okl);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
@@ -366,7 +366,7 @@ Forks::Super::Util - utility routines for Forks::Super module
 
 =head1 VERSION
 
-0.77
+0.78
 
 =head1 SYNOPSIS
 
@@ -376,7 +376,7 @@ Forks::Super::Util - utility routines for Forks::Super module
 =head1 DESCRIPTION
 
 A collection of useful and mostly unrelated routines for things
-that the L<Forks::Super> distribution needs to do.
+that the L<Forks::Super|Forks::Super> distribution needs to do.
 
 =head1 SUBROUTINES
 
@@ -488,7 +488,7 @@ that the function actually waited.
 
 Prepends a package qualifier from the current context, if necessary,
 from current execution context of a scalar subroutine name. Used when
-an unqualified subroutine name is passed in any L<Forks::Super>
+an unqualified subroutine name is passed in any L<Forks::Super|Forks::Super>
 function argument that expects a code reference.
 
     package Foo;
@@ -501,8 +501,8 @@ function argument that expects a code reference.
 =head2 set_productive_pause_code($coderef)
 
 Specifies the code that the L<"pause"> method should run during
-down time. In most L<Forks::Super> programs, the default will be
-to check if running processes have completed and to manage tasks
+down time. In most L<Forks::Super|Forks::Super> programs, the default 
+will be to check if running processes have completed and to manage tasks
 in the job queue.
 
 Can be called with an C<undef> argument to disable productive
@@ -524,7 +524,7 @@ signal name.
 
 =head1 SEE ALSO
 
-L<Forks::Super>
+L<Forks::Super|Forks::Super>
 
 =head1 AUTHOR
 
