@@ -21,7 +21,7 @@ use warnings;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(wait waitpid waitall TIMEOUT WREAP_BG_OK);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
-our $VERSION = '0.77';
+our $VERSION = '0.78';
 
 my ($productive_waitpid_code);
 my $respect_SIGCHLD_ignore = 1;
@@ -40,7 +40,7 @@ use constant WREAP_BG_OK => WNOHANG() << 1;
 use constant _BRIEF_TIMEOUT => 1E-6; # seconds
 use constant FOREVER => 9.0E9;       # to a first order 285 years is forever
 
-sub wait {
+sub Forks::Super::Wait::wait {
     my $timeout = shift || 0;
     if ($timeout < 0) {
 	$timeout = _BRIEF_TIMEOUT;
@@ -66,7 +66,7 @@ sub _cleanse_waitpid_args {
     return ($flags, $timeout);
 }
 
-sub waitpid {
+sub Forks::Super::Wait::waitpid {
     my $target = shift;
     my ($flags, $timeout) = _cleanse_waitpid_args(@_);
 
@@ -528,7 +528,7 @@ Forks::Super::Wait
 
 =head1 VERSION
 
-0.77
+0.78
 
 =head1 DESCRIPTION
 
