@@ -11,10 +11,14 @@
 # amount of time, producing simple output to a file, determining
 # environment like the PPID, and exiting with an arbitrary exit code.
 #
-#   -s=n          go to sleep for <n> seconds
 #   -e=msg        writes the msg to standard output or output
+#   -F            output program status when the program exits
+#   -n            writes a newline to standard output or output
 #   -o=file       redirect standard output to file
 #   -p            outputs the parent PID
+#   -P,-W         outputs process id
+#   -s=n          go to sleep for <n> seconds
+#   -w=msg        writes the msg to standard error
 #   -x=z          exit with code <z>
 #   -y=n          print line from STDIN <n> times to STDOUT, once to STDERR
 #
@@ -26,11 +30,16 @@
 # This script is used in tests:
 #      t/11-to-command.t
 #      t/13-to-exec.t
-#      t/40-timeout.t
-#      t/42-filehandle.t
-#      t/45-userbusy.t
+#      t/25-open.t
+#      t/26-waitpid-MSWin32-pgrp.t
+#      t/40h-timeout.t
+#      t/42[abcef]-filehandle.t
+#      t/43e-sockethandles.t
+#      t/46b-userbusy.t
+#      t/56a-dir.t
 #      t/60-os.t
-#      t/63-bg_qx.t
+#      t/63a-bg_qx.t
+#      t/63b-bg_qx_tie.t
 #
 
 
@@ -65,6 +74,8 @@ foreach my $arg (@ARGV) {
 	$| = 1;
     } elsif ($key eq '--echo' or $key eq '-e') {
 	print $val, ' ';
+    } elsif ($key eq '--warn' or $key eq '-w') {
+	print STDERR $val, ' ';
     } elsif ($key eq '--ppid' or $key eq '-p') {
 	# On MSWin32, getppid() is broken. 
 	my $ppid = $^O eq 'MSWin32' ? $ENV{_FORK_PPID} : getppid();
